#!/bin/csh

# 1) set yMODE to Complex instead of Echo-AntiEcho before the two interleaved
#    data sets are separated, and then use the bruk_ranceY.M macro to reshuffle
#    the echo and antiecho data to convert the phase modulated data to amplitude
#    modulated data.

# 2) set yN to the total number of FIDs recorded for both experiments. Round it down
#    so that it can be divided by 8 for the interleaved data.

# 3) zN should be set to 1 and zMODE set to Real instead of complex

# 4) It is important to set ndim to 2 to treat the 3D as 2D before NUS expansion

# 5) After the conversion, each separate data set is then reshuffled and NUS expanded

rm -fr test.fid

bruk2pipe -verb -in ./ser \
  -bad 0.0 -ext -aswap -AMX -decim 1520 -dspfvs 20 -grpdly 68 -ws 8 -noi2f  \
  -xN              3072  -yN              8320  -zN                 1  \
  -xT              1536  -yT               160  -zT                26  \
  -xMODE            DQD  -yMODE        Complex  -zMODE           Real  \
  -xSW        13157.895  -ySW         2906.977  -zSW         3225.806  \
  -xOBS         900.274  -yOBS          91.234  -zOBS         226.412  \
  -xCAR           4.677  -yCAR         116.735  -zCAR         175.945  \
  -xLAB              HN  -yLAB             15N  -zLAB             13C  \
  -ndim               2  -aq2D         Complex                         \
  -out test.fid -ov

rm -fr fid

#make sure the highest S/N spectrum must have idxExpmt=1
set tauValues = ( 5.375 10.750 )
set idxExpmt  = (     1      2 )

set nExp=${#tauValues}
set n=1
set bits=()

while ( $n <= $nExp )
   set bits = ($bits 0)
   @ n++
end

foreach n (`seq 1 $nExp`)
   echo Time t${n} \($tauValues[$n] ms\)...

   set bits[$n] = 1
   echo $bits

   set outName = (`printf fid/test%03d.fid $idxExpmt[$n]`)
   echo "* output = $outName"

   rm -fr temp.fid  #critical if -ov not used below for overwriting
   nmrPipe -in test.fid \
   | nmrPipe -fn COADD -cList $bits -axis Y -out temp.fid -ov

   nusExpand.tcl -mode pipe -in temp.fid -out $outName -qzSize 2 \
                 -sample nuslist -sampleCount 1040 -yT 160 -zT 26

   sethdr $outName -tau $tauValues[$n]

   set bits[$n] = 0
end

rm -fr temp.fid test.fid

